@@ -1,8 +1,9 @@
 package Mail::BIMI;
-# ABSTRACT: Class to model a collection of egress pools
-our $VERSION = '1.20200210'; # VERSION
+# ABSTRACT: BIMI object
+our $VERSION = '1.20200214'; # VERSION
 use 5.20.0;
 use Moo;
+use Carp;
 use Types::Standard qw{Str HashRef ArrayRef};
 use Type::Utils qw{class_type};
 use Mail::BIMI::Pragmas;
@@ -21,17 +22,20 @@ use Mail::BIMI::Result;
   has result => ( is => 'rw', lazy => 1, builder => '_build_result' );
 
 sub _build_record($self) {
+  croak 'Domain required' if ! $self->domain;
   return Mail::BIMI::Record->new( domain => $self->domain, selector => $self->selector, resolver => $self->resolver );
 }
 
 sub _build_result($self) {
+  croak 'Domain required' if ! $self->domain;
+
   my $result = Mail::BIMI::Result->new(
     parent => $self,
   );
 
   # does DMARC pass
   if ( ! $self->dmarc_object ) {
-    $result->set_result( 'skipped', 'no DMARC' );
+    $result->set_result( 'skipped', $self->NO_DMARC );
     return $result;
   }
   if ( $self->dmarc_object->result ne 'pass' ) {
@@ -48,7 +52,7 @@ sub _build_result($self) {
               if ( @spf_terms ) {
                     my $last_term = pop @spf_terms;
                     if ( $last_term->name eq 'all' && $last_term->qualifier eq '+') {
-                        $result->set_result( 'skipped', 'SPF +all detected' );
+                        $result->set_result( 'skipped', $self->SPF_PLUS_ALL );
                         return $result;
                     }
                 }
@@ -56,17 +60,15 @@ sub _build_result($self) {
         }
     }
 
-  if ( ! $self->record ) {
-    $result->set_result( 'none', 'No BIMI Record' );
-    return $result;
-  }
-
   if ( ! $self->record->is_valid ) {
     if ( $self->record->has_error( $self->NO_BIMI_RECORD ) ) {
-      $result->set_result( 'none', 'Domain is not BIMI enabled' );
+      $result->set_result( 'none', $self->BIMI_NOT_ENABLED );
+    }
+    elsif ( $self->record->has_error( $self->DNS_ERROR ) ) {
+      $result->set_result( 'none', $self->DNS_ERROR );
     }
     else {
-      $result->set_result( 'fail', 'Invalid BIMI Record' );
+      $result->set_result( 'fail', $self->BIMI_INVALID );
     }
     return $result;
   }
