@@ -1,12 +1,13 @@
 package Mail::BIMI::Record::Location;
-# ABSTRACT: Class to model a collection of egress pools
-our $VERSION = '1.20200210'; # VERSION
+# ABSTRACT: Class to model a BIMI location
+our $VERSION = '1.20200214'; # VERSION
 use 5.20.0;
 use Moo;
 use Types::Standard qw{Str HashRef ArrayRef};
 use Type::Utils qw{class_type};
 use Mail::BIMI::Pragmas;
   with 'Mail::BIMI::Role::Error';
+  with 'Mail::BIMI::Role::Constants';
   has location => ( is => 'rw', isa => ArrayRef, required => 1 );
   has is_valid => ( is => 'rw', lazy => 1, builder => '_build_is_valid' );
 
@@ -17,7 +18,7 @@ sub _build_is_valid($self) {
       $self->add_error( 'Empty l tag' );
     }
     elsif ( ! ( $location =~ /^https:\/\// ) ) {
-      $self->add_error( 'Invalid transport in locations' );
+      $self->add_error( $self->INVALID_TRANSPORT );
     }
   }
 
